MsalWorkplaceJoinRequiredException class

Workplace join is required to proceed. Handling of this error is optional.

Only occurs in iOS/MacOS platform.

Inheritance

Constructors

MsalWorkplaceJoinRequiredException({required String message, required String? correlationId})
const

Properties

correlationId → String?
Represents UUID used for the request.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
message → String
Error message returned by MSAL SDK.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited